***************************** Database Management *****************************;

** Path to the file named : JFE data and code **;

	%LET path = C:\Users\sebsa\OneDrive\Documents\Recherche Reproductible\Reproductible;

** Database importations **;

	* Importation of the sheet "data_authors" from the file named : JFE data and code *;

	OPTIONS VALIDVARNAME=V7;

	PROC IMPORT DATAFILE="&path.\JFE data and code.xlsx" OUT=data_authors replace DBMS=xlsx;
				SHEET="data_authors";
	QUIT;

	* Importation of the sheet "data_papers" from the file named : JFE data and code *;

	PROC IMPORT DATAFILE="&path.\JFE data and code.xlsx" OUT=data_papers replace DBMS=xlsx;
				SHEET="data_papers";
	QUIT;

	* Table "data_authors" : Delete lines and columns which does not contain any useful information *;

	DATA data_authors;
		SET data_authors;
		IF _N_ >= 1348 THEN DELETE; 
		DROP H; 
	RUN;

** Merge of the database "data_authors" and "data_papers" by author number, year of publication, volume
   and issue **;

%MACRO fusion;

/* Merge with the first author */

 	/* We retrieve in a new table "AUTHOR_1" the rows from "data_authors" with "Author__" = 1 */

	PROC SQL;	
		CREATE TABLE AUTHOR_1 AS
		SELECT *
		FROM data_authors
		WHERE Author__ = 1;
	QUIT;

	/* We sort this new table by "AUTHOR", "YEAR", "VOLUME" and "ISSUE" */

	PROC SORT DATA=AUTHOR_1;
		BY AUTHOR YEAR VOLUME ISSUE;
	RUN;

	/* We also sort the table "data_papers" by "Author_1", "Publication_Year", "Volume"
	  and "Issue" : the result is saved in a new table named "Merge1" */

	PROC SORT DATA=data_papers OUT=Merge1;
		BY Author_1 Publication_Year Volume Issue;
	RUN;
		
	/* Merge of the table "AUTHOR_1" and "Merge1" by "Author_1" "Publication_Year" "Volume" "Issue".

	Number of paper obtained : 1 347 */
 
	DATA fusion1;
		/* We delete the column "Author__" from the table "AUTHOR_1" and we rename the columns 
		   "AUTHOR" and "YEAR" to merge this table with the table "Merge1" by 
		   "Author_1" "Publication_Year" "Volume" "Issue" */ 
		MERGE AUTHOR_1(DROP=Author__ rename=(AUTHOR=Author_1 YEAR=Publication_Year)) Merge1;
		/* Creation of the variable "Citations_Year_1" which contains the number of citations of authors 1 */
		Citations_Year_1 = Citations_Year ;
		/* Creation of the variable "ENTRY_1" which contains ... */
		ENTRY_1 = ENTRY;
		/* Merge keys */
		BY Author_1 Publication_Year Volume Issue;
		/* Delete columns "ENTRY" and "Citations_Year" */
		DROP ENTRY Citations_Year; 
	RUN;

	/* Same approach for authors 2 to 6 */

	%DO num_auteur = 2 %TO 6; /* Start of the loop */

	%LET ancien_auteur = %SYSEVALF(&num_auteur - 1); /* Number of the author' number at the previous 
														iteration */

	/* Merge with the ith author */

	PROC SQL;	
		CREATE TABLE AUTHOR_&num_auteur. AS
		SELECT *
		FROM data_authors
		WHERE Author__ = &num_auteur.;
	QUIT;

	/* We retrieve in a new table "AUTHOR_i" the rows from "data_authors" with "Author__" = i */

	PROC SQL;	
		CREATE TABLE AUTHOR_&num_auteur. AS
		SELECT *
		FROM data_authors
		WHERE Author__ = &num_auteur.;
	QUIT;

	/* We sort this new table by "AUTHOR", "YEAR", "VOLUME" and "ISSUE" */
	
	PROC SORT DATA=AUTHOR_&num_auteur.;
		BY AUTHOR YEAR VOLUME ISSUE;
	RUN;

	/* We also sort the table "data_papers" by "Author_i", "Publication_Year", "Volume"
	  and "Issue" : the result is saved in a new table named "Mergei" */

	PROC SORT DATA=fusion&ancien_auteur. OUT=Merge&num_auteur.; 
		BY Author_&num_auteur. Publication_Year Volume Issue;
	RUN;

	/* Merge of the table "AUTHOR_i" and "Mergei" by "Author_i" "Publication_Year" "Volume" "Issue".

	Number of paper obtained : 1 347 */

	DATA fusion&num_auteur.;
		/* We delete the column "Author__" from the table "AUTHOR_i" and we rename the columns 
		   "AUTHOR" and "YEAR" to merge this table with the table "Mergei" by 
		   "Author_i" "Publication_Year" "Volume" "Issue" */ 
		MERGE AUTHOR_&num_auteur.(DROP=Author__ rename=(AUTHOR=Author_&num_auteur. YEAR=Publication_Year)) 
			  Merge&num_auteur.;
		/* Merge keys */
		BY Author_&num_auteur. Publication_Year Volume Issue;
		/* Creation of the variable "Citations_Year_i" which contains the number of citations of authors i */
		Citations_Year_&num_auteur. = Citations_Year ;*/
		/* Creation of the variable "ENTRY_1" which contains ... */;
		ENTRY_&num_auteur. = ENTRY;
		/* Delete columns "ENTRY" and "Citations_Year" */
		DROP ENTRY Citations_Year; 
	RUN;

	%END; /* End of the loop */

%MEND;

%fusion


/* We sort the final table "fusion6" by "ID".
   We save this result in a new table named : "fin" */

PROC SORT DATA=fusion6 OUT=fin;
	BY ID;
RUN;

/* We save this new SAS table in the folder containing initial files, as "fusion" */

	LIBNAME store "&path.";

	DATA store.fusion;	
		SET fin;
	RUN;


DATA fusion;	
	SET store.fusion;

	/* If the variable "OPEN" is missing, i.e., data and/or codes are not shared, the "OPEN" = 0 * */

	IF MISSING(OPEN) THEN OPEN = 0;
	ELSE OPEN = 1;

	ARRAY senioritys{*} seniority1-seniority6;
	ARRAY entry{*} ENTRY_1-ENTRY_6;
	ARRAY citations_year{*} $ citations_year_1-citations_year_6;

	* Loop on author number by paper *;

	DO i=1 TO 6; /* 6 = maximum number of authors by paper */

		/* If we have information on the variable "ENTRY" then we calculate author's seniority ... */
		  
		IF MISSING(entry{i}) = 0 and entry{i} ^= "na" THEN DO;
				senioritys{i} = publication_year - entry{i};
		END;

		/* ... else, the seniority is set to a missing value */
		
		ELSE senioritys{i} = .;
		
		/* If the number of citations of the ith author is equal to "na" then we change it to a missing
		   value */
	
		IF citations_year{i} = "na" THEN CALL MISSING(citations_year{i});
	END;

	/* Mean of seniority and citations */
	
	mean_seniority = MEAN(OF seniority:); * Generate missing values when all seniorities are missing *;

	mean_citations = MEAN(OF citations_year:); * Generate missing values when all citations are missing *;

	/* Internation variable creation */

	IF VAR14 = "u" THEN international = 0; /* i : international , u : US or Canada */
	ELSE international = 1;

	DROP i seniority1-seniority6 citations_year:; /*  citations_year:*/
RUN;

/* Exportation of this table to an excel file in the folder containing initial files, as "Data_JFE" */

PROC EXPORT DATA=fusion
			OUTFILE="&path.\Data_JFE"
			replace
			DBMS=XLSX;
RUN;
